
# Type: sequence variant_has biological sequence




URI: [biolink:sequence_variant_has_biological_sequence](https://w3id.org/biolink/vocab/sequence_variant_has_biological_sequence)


## Domain and Range

[SequenceVariant](SequenceVariant.md) ->  <sub>OPT</sub> [BiologicalSequence](types/BiologicalSequence.md)

## Parents

 *  is_a: [has biological sequence](has_biological_sequence.md)

## Children


## Used by

 * [SequenceVariant](SequenceVariant.md)
